#Program to extract learning curves from the EDL learner's output.
#To download the learning software, visit:
#https://github.com/gajajarosz/hidden-structure
####################################################################
import re
from sys import exit, argv
from numpy import mean
import numpy as np

rep_num = int(argv[1]) #Number of total repetitions in the data
pattnames = ["Bleeding", "Feeding", "Counterbleeding", "Counterfeeding"]
reps = [str(r) for r in range(1,rep_num+1)] #List of reps to loop through

#Test data (UR, correct SR, incorrect SR):
test_data = {
				"Faithful_ta":{	"Bleeding": ["tA", "tA", "cA"],
								"Feeding": ["tA", "tA", "cA"],
								"Counterbleeding": ["tA", "tA", "cA"],
								"Counterfeeding": ["tA", "tA", "cA"]
							  },
				"Faithful_ka":{	"Bleeding": ["kA", "kA", "cA"],
								"Feeding": ["kA", "kA", "cA"],
								"Counterbleeding": ["kA", "kA", "cA"],
								"Counterfeeding": ["kA", "kA", "cA"]
							  },
				"Faithful_ki":{	"Bleeding": ["kI", "kI", "cI"],
								"Feeding": ["kI", "kI", "cI"],
								"Counterbleeding": ["kI", "kI", "cI"],
								"Counterfeeding": ["kI", "kI", "cI"]
							  },
				"Hiatus":{	"Bleeding": ["kiA", "kA", "kiA"],
							"Feeding": ["kaI", "kI", "kaI"],
							"Counterbleeding": ["kiA", "kA", "kiA"],
							"Counterfeeding": ["kaI", "kI", "kaI"]
						  },
				"Palatalizing":{	"Bleeding": ["tI", "cI", "tI"],
								"Feeding": ["tI", "cI", "tI"],
								"Counterbleeding": ["tI", "cI", "tI"],
								"Counterfeeding": ["tI", "cI", "tI"]
							  },
				"Interacting":{	"Bleeding": ["tiA", "tA", "cA"],
								"Feeding": ["taI", "cI", "tI"],
								"Counterbleeding": ["tiA", "cA", "tA"],
								"Counterfeeding": ["taI", "tI", "cI"]
							  }
			}
ur2trialType = {"tA":"Faithful_ta", "kI":"Faithful_ki", "kA":"Faithful_ka", "kiA":"Hiatus",
				"kaI":"Hiatus", "tI":"Palatalizing", "tiA":"Interacting", "taI":"Interacting"}

#Start loop:
tt_curve_file = open("Curves by trial type (EDL-ForcedChoice).csv", "w")
tt_curve_file.write("Trial Type,Pattern,Rep,Epoch,Accuracy\n")
this_iteration = -1
for patt_i, patt in enumerate(pattnames):
	these_probs = {tt:{"wrong":0.0, "right":0.0} for tt in test_data.keys()}
	for rep in reps:
		this_file = open("EDL_Outputs\\"+rep+patt+"_output.txt")
		for line in this_file:		
			iter_line = re.search("Starting iteration ([0-9]+)", line)	
			UR_line = re.search("Surface forms produced from (.+)", line)
			cand_line = re.search("(.+) form - (.+) \(p=([0-9.]+)\)", line)
			
			#If we're at a new iteration, save last iteration's info:
			if iter_line:
				if this_iteration >= 0:
					for tt in test_data.keys():
						try:
							wrong = iteration_probs[tt+"-wrong"]
						except: 
							wrong = 0.0
						right = iteration_probs[tt+"-right"]
						this_acc = right/float(right+wrong)
						if this_iteration == 19:
							if rep == "1":
								tt_curve_file.write(tt+","+pattnames[patt_i-1]+","+str(20)+","+str(this_iteration)+","+str(this_acc)+"\n")
							else:
								tt_curve_file.write(tt+","+patt+","+str(int(rep)-1)+","+str(this_iteration)+","+str(this_acc)+"\n")
						else:
							tt_curve_file.write(tt+","+patt+","+str(rep)+","+str(this_iteration)+","+str(this_acc)+"\n")
				
				#...And update these variables:
				this_iteration = int(iter_line.group(1))
				iteration_probs = {}
			#If we're at a new UR, figure out the info for that:
			if UR_line:
				this_ur = UR_line.group(1)
				this_tt = ur2trialType[this_ur]
				correct_ur = test_data[this_tt][patt][0]
				correct_sr = test_data[this_tt][patt][1]
				wrong_sr = test_data[this_tt][patt][2]
				if this_ur != correct_ur:
					print (this_ur, correct_ur)
					exit("UR Error!")
			#If we're at a new candidate (SR), store the info for that:
			if cand_line:
				this_cand = cand_line.group(2)
				is_correct = ("Correct" in cand_line.group(1))
				prob = float(cand_line.group(3))
				
				if is_correct and (this_cand != correct_sr):
					print (this_cand, correct_sr)
					exit("SR Error!")
				if is_correct:
					iteration_probs[this_tt+"-right"] = prob
				elif this_cand == wrong_sr:
					iteration_probs[this_tt+"-wrong"] = prob

for tt in test_data.keys():
	try:
		wrong = iteration_probs[tt+"-wrong"]
	except: 
		wrong = 0.0
	right = iteration_probs[tt+"-right"]
	this_acc = right/float(right+wrong)
	tt_curve_file.write(tt+","+patt+","+str(rep_num)+","+str(19)+","+str(this_acc)+"\n")
				

tt_curve_file.close() #Close output file.
			

	
	
	
	
	
	